# coding=utf-8

import bisect
from faker.generator import random as mod_random


def random_sample(random=None):
    if random is None:
        random = mod_random
    return random.uniform(0.0, 1.0)


def cumsum(it):
    total = 0
    for x in it:
        total += x
        yield total


def choice_distribution(a, p, random=None):
    if random is None:
        random = mod_random

    assert len(a) == len(p)

    if hasattr(random, 'choices'):
        return random.choices(a, weights=p)[0]
    else:
        cdf = list(cumsum(p))
        normal = cdf[-1]
        cdf2 = [float(i) / float(normal) for i in cdf]
        uniform_sample = random_sample(random=random)
        idx = bisect.bisect_right(cdf2, uniform_sample)
        return a[idx]



# coding=utf-8

from __future__ import unicode_literals
from .. import Provider as PersonProvider


class Provider(PersonProvider):
    formats = (
        '{{first_name_male}} {{last_name}}',
        '{{first_name_male}} {{last_name}}',
        '{{first_name_male}} {{last_name}}',
        '{{first_name_male}} {{last_name}}',
        '{{first_name_female}} {{last_name}}',
        '{{first_name_female}} {{last_name}}',
        '{{first_name_female}} {{last_name}}',
        '{{first_name_female}} {{last_name}}',
        '{{prefix_male}} {{first_name_male}} {{last_name}}',
        '{{prefix_female}} {{first_name_female}} {{last_name}}',
        '{{first_name_male}} {{last_name}}, {{suffix}}',
        '{{first_name_female}} {{last_name}}, {{suffix}}',
        '{{prefix_male}} {{first_name_male}} {{last_name}}, {{suffix}}',
        '{{prefix_female}} {{first_name_female}} {{last_name}}, {{suffix}}',
    )

    # From http://www.nama.web.id/search.php?gender=male&origin=Indonesia+-+Jawa&letter=&submit=Search
    # via
    # https://github.com/fzaninotto/faker/blob/master/src/Faker/Provider/id_ID/Person.php
    first_names_male = (
        'Abyasa', 'Ade', 'Adhiarja', 'Adiarja', 'Adika', 'Adikara', 'Adinata',
        'Aditya', 'Agus', 'Ajiman', 'Ajimat', 'Ajimin', 'Ajiono', 'Akarsana',
        'Alambana', 'Among', 'Anggabaya', 'Anom', 'Argono', 'Aris', 'Arta',
        'Artanto', 'Artawan', 'Arsipatra', 'Asirwada', 'Asirwanda', 'Aslijan',
        'Asmadi', 'Asman', 'Asmianto', 'Asmuni', 'Aswani', 'Atma', 'Atmaja',
        'Bagas', 'Bagiya', 'Bagus', 'Bagya', 'Bahuraksa', 'Bahuwarna',
        'Bahuwirya', 'Bajragin', 'Bakda', 'Bakiadi', 'Bakianto', 'Bakidin',
        'Bakijan', 'Bakiman', 'Bakiono', 'Bakti', 'Baktiadi', 'Baktianto',
        'Baktiono', 'Bala', 'Balamantri', 'Balangga', 'Balapati', 'Balidin',
        'Balijan', 'Bambang', 'Banara', 'Banawa', 'Banawi', 'Bancar', 'Budi',
        'Cagak', 'Cager', 'Cahyadi', 'Cahyanto', 'Cahya', 'Cahyo', 'Cahyono',
        'Caket', 'Cakrabirawa', 'Cakrabuana', 'Cakrajiya', 'Cakrawala',
        'Cakrawangsa', 'Candra', 'Chandra', 'Candrakanta', 'Capa', 'Caraka',
        'Carub', 'Catur', 'Caturangga', 'Cawisadi', 'Cawisono', 'Cawuk',
        'Cayadi', 'Cecep', 'Cemani', 'Cemeti', 'Cemplunk', 'Cengkal', 'Cengkir',
        'Dacin', 'Dadap', 'Dadi', 'Dagel', 'Daliman', 'Dalimin', 'Daliono',
        'Damar', 'Damu', 'Danang', 'Daniswara', 'Danu', 'Danuja', 'Dariati',
        'Darijan', 'Darimin', 'Darmaji', 'Darman', 'Darmana', 'Darmanto',
        'Darsirah', 'Dartono', 'Daru', 'Daruna', 'Daryani', 'Dasa', 'Digdaya',
        'Dimas', 'Dimaz', 'Dipa', 'Dirja', 'Drajat', 'Dwi', 'Dono', 'Dodo',
        'Edi', 'Eka', 'Elon', 'Eluh', 'Eman', 'Emas', 'Embuh', 'Emong',
        'Empluk', 'Endra', 'Enteng', 'Estiawan', 'Estiono', 'Eko', 'Edi',
        'Edison', 'Edward', 'Elvin', 'Erik', 'Emil', 'Ega', 'Emin', 'Eja',
        'Gada', 'Gadang', 'Gaduh', 'Gaiman', 'Galak', 'Galang', 'Galar',
        'Galih', 'Galiono', 'Galuh', 'Galur', 'Gaman', 'Gamani', 'Gamanto',
        'Gambira', 'Gamblang', 'Ganda', 'Gandewa', 'Gandi', 'Gandi', 'Ganep',
        'Gangsa', 'Gangsar', 'Ganjaran', 'Gantar', 'Gara', 'Garan', 'Garang',
        'Garda', 'Gatot', 'Gatra', 'Gilang', 'Galih', 'Ghani', 'Gading',
        'Hairyanto', 'Hardana', 'Hardi', 'Harimurti', 'Harja', 'Harjasa',
        'Harjaya', 'Harjo', 'Harsana', 'Harsanto', 'Harsaya', 'Hartaka',
        'Hartana', 'Harto', 'Hasta', 'Heru', 'Himawan', 'Hadi', 'Halim',
        'Hasim', 'Hasan', 'Hendra', 'Hendri', 'Heryanto', 'Hamzah', 'Hari',
        'Imam', 'Indra', 'Irwan', 'Irsad', 'Ikhsan', 'Irfan', 'Ian', 'Ibrahim',
        'Ibrani', 'Ismail', 'Irnanto', 'Ilyas', 'Ibun', 'Ivan', 'Ikin', 'Ihsan',
        'Jabal', 'Jaeman', 'Jaga', 'Jagapati', 'Jagaraga', 'Jail', 'Jaiman',
        'Jaka', 'Jarwa', 'Jarwadi', 'Jarwi', 'Jasmani', 'Jaswadi', 'Jati',
        'Jatmiko', 'Jaya', 'Jayadi', 'Jayeng', 'Jinawi', 'Jindra', 'Joko',
        'Jumadi', 'Jumari', 'Jamal', 'Jamil', 'Jais', 'Jefri', 'Johan', 'Jono',
        'Kacung', 'Kajen', 'Kambali', 'Kamidin', 'Kariman', 'Karja', 'Karma',
        'Karman', 'Karna', 'Karsa', 'Karsana', 'Karta', 'Kasiran', 'Kasusra',
        'Kawaca', 'Kawaya', 'Kayun', 'Kemba', 'Kenari', 'Kenes', 'Kuncara',
        'Kunthara', 'Kusuma', 'Kadir', 'Kala', 'Kalim', 'Kurnia', 'Kanda',
        'Kardi', 'Karya', 'Kasim', 'Kairav', 'Kenzie', 'Kemal', 'Kamal', 'Koko',
        'Labuh', 'Laksana', 'Lamar', 'Lanang', 'Langgeng', 'Lanjar', 'Lantar',
        'Lega', 'Legawa', 'Lembah', 'Liman', 'Limar', 'Luhung', 'Lukita',
        'Luluh', 'Lulut', 'Lurhur', 'Luwar', 'Luwes', 'Latif', 'Lasmanto',
        'Lukman', 'Luthfi', 'Leo', 'Luis', 'Lutfan', 'Lasmono', 'Laswi',
        'Mahesa', 'Makara', 'Makuta', 'Manah', 'Maras', 'Margana', 'Mariadi',
        'Marsudi', 'Martaka', 'Martana', 'Martani', 'Marwata', 'Maryadi',
        'Maryanto', 'Mitra', 'Mujur', 'Mulya', 'Mulyanto', 'Mulyono', 'Mumpuni',
        'Muni', 'Mursita', 'Murti', 'Mustika', 'Maman', 'Mahmud', 'Mahdi',
        'Mahfud', 'Malik', 'Muhammad', 'Mustofa', 'Marsito', 'Mursinin',
        'Nalar', 'Naradi', 'Nardi', 'Niyaga', 'Nrima', 'Nugraha', 'Nyana',
        'Narji', 'Nasab', 'Nasrullah', 'Nasim', 'Najib', 'Najam', 'Nyoman',
        'Olga', 'Ozy', 'Omar', 'Opan', 'Oskar', 'Oman', 'Okto', 'Okta', 'Opung',
        'Paiman', 'Panca', 'Pangeran', 'Pangestu', 'Pardi', 'Parman', 'Perkasa',
        'Praba', 'Prabu', 'Prabawa', 'Prabowo', 'Prakosa', 'Pranata', 'Pranawa',
        'Prasetya', 'Prasetyo', 'Prayitna', 'Prayoga', 'Prayogo', 'Purwadi',
        'Purwa', 'Purwanto', 'Panji', 'Pandu', 'Paiman', 'Prima', 'Putu',
        'Raden', 'Raditya', 'Raharja', 'Rama', 'Rangga', 'Reksa', 'Respati',
        'Rusman', 'Rosman', 'Rahmat', 'Rahman', 'Rendy', 'Reza', 'Rizki',
        'Ridwan', 'Rudi', 'Raden', 'Radit', 'Radika', 'Rafi', 'Rafid', 'Raihan',
        'Salman', 'Saadat', 'Saiful', 'Surya', 'Slamet', 'Samsul', 'Soleh',
        'Simon', 'Sabar', 'Sabri', 'Sidiq', 'Satya', 'Setya', 'Saka', 'Sakti',
        'Taswir', 'Tedi', 'Teddy', 'Taufan', 'Taufik', 'Tomi', 'Tasnim',
        'Teguh', 'Tasdik', 'Timbul', 'Tirta', 'Tirtayasa', 'Tri', 'Tugiman',
        'Umar', 'Usman', 'Uda', 'Umay', 'Unggul', 'Utama', 'Umaya', 'Upik',
        'Viktor', 'Vino', 'Vinsen', 'Vero', 'Vega', 'Viman', 'Virman',
        'Wahyu', 'Wira', 'Wisnu', 'Wadi', 'Wardi', 'Warji', 'Waluyo', 'Wakiman',
        'Wage', 'Wardaya', 'Warsa', 'Warsita', 'Warta', 'Wasis', 'Wawan',
        'Xanana', 'Yahya', 'Yusuf', 'Yosef', 'Yono', 'Yoga',
    )

    # From http://namafb.com/2010/08/12/top-1000-nama-populer-indonesia/
    # via
    # https://github.com/fzaninotto/faker/blob/master/src/Faker/Provider/id_ID/Person.php
    first_names_female = (
        'Ade', 'Agnes', 'Ajeng', 'Amalia', 'Anita', 'Ayu', 'Aisyah', 'Ana',
        'Ami', 'Ani', 'Azalea', 'Aurora', 'Alika', 'Anastasia', 'Amelia',
        'Almira', 'Bella', 'Betania', 'Belinda', 'Citra', 'Cindy', 'Chelsea',
        'Clara', 'Cornelia', 'Cinta', 'Cinthia', 'Ciaobella', 'Cici', 'Carla',
        'Calista', 'Devi', 'Dewi', 'Dian', 'Diah', 'Diana', 'Dina', 'Dinda',
        'Dalima', 'Eka', 'Eva', 'Endah', 'Elisa', 'Eli', 'Ella', 'Ellis',
        'Elma', 'Elvina', 'Fitria', 'Fitriani', 'Febi', 'Faizah', 'Farah',
        'Farhunnisa', 'Fathonah', 'Gabriella', 'Gasti', 'Gawati', 'Genta',
        'Ghaliyati', 'Gina', 'Gilda', 'Halima', 'Hesti', 'Hilda', 'Hafshah',
        'Hamima', 'Hana', 'Hani', 'Hasna', 'Humaira', 'Ika', 'Indah', 'Intan',
        'Irma', 'Icha', 'Ida', 'Ifa', 'Ilsa', 'Ina', 'Ira', 'Iriana', 'Jamalia',
        'Janet', 'Jane', 'Julia', 'Juli', 'Jessica', 'Jasmin', 'Jelita',
        'Kamaria', 'Kamila', 'Kani', 'Karen', 'Karimah', 'Kartika', 'Kasiyah',
        'Keisha', 'Kezia', 'Kiandra', 'Kayla', 'Kania', 'Lala', 'Lalita',
        'Latika', 'Laila', 'Laras', 'Lidya', 'Lili', 'Lintang', 'Maria', 'Mala',
        'Maya', 'Maida', 'Maimunah', 'Melinda', 'Mila', 'Mutia', 'Michelle',
        'Malika', 'Nadia', 'Nadine', 'Nabila', 'Natalia', 'Novi', 'Nova',
        'Nurul', 'Nilam', 'Najwa', 'Olivia', 'Ophelia', 'Oni', 'Oliva', 'Padma',
        'Putri', 'Paramita', 'Paris', 'Patricia', 'Paulin', 'Puput', 'Puji',
        'Pia', 'Puspa', 'Puti', 'Putri', 'Padmi', 'Qori', 'Queen', 'Ratih',
        'Ratna', 'Restu', 'Rini', 'Rika', 'Rina', 'Rahayu', 'Rahmi', 'Rachel',
        'Rahmi', 'Raisa', 'Raina', 'Sarah', 'Sari', 'Siti', 'Siska', 'Suci',
        'Syahrini', 'Septi', 'Sadina', 'Safina', 'Sakura', 'Salimah', 'Salwa',
        'Salsabila', 'Samiah', 'Shania', 'Sabrina', 'Silvia', 'Shakila',
        'Talia', 'Tami', 'Tira', 'Tiara', 'Titin', 'Tania', 'Tina', 'Tantri',
        'Tari', 'Titi', 'Uchita', 'Unjani', 'Ulya', 'Uli', 'Ulva', 'Umi',
        'Usyi', 'Vanya', 'Vanesa', 'Vivi', 'Vera', 'Vicky', 'Victoria',
        'Violet', 'Winda', 'Widya', 'Wulan', 'Wirda', 'Wani', 'Yani', 'Yessi',
        'Yulia', 'Yuliana', 'Yuni', 'Yunita', 'Yance', 'Zahra', 'Zalindra',
        'Zaenab', 'Zulfa', 'Zizi', 'Zulaikha', 'Zamira', 'Zelda', 'Zelaya',
    )

    first_names = first_names_male + first_names_female

    # From http://namafb.com/2010/08/12/top-1000-nama-populer-indonesia/
    # From http://id.wikipedia.org/wiki/Daftar_marga_suku_Batak_di_Toba
    # via
    # https://github.com/fzaninotto/faker/blob/master/src/Faker/Provider/id_ID/Person.php
    last_names_male = (
        'Adriansyah', 'Ardianto', 'Anggriawan', 'Budiman', 'Budiyanto',
        'Damanik', 'Dongoran', 'Dabukke', 'Firmansyah', 'Firgantoro',
        'Gunarto', 'Gunawan', 'Hardiansyah', 'Habibi', 'Hakim', 'Halim',
        'Haryanto', 'Hidayat', 'Hidayanto', 'Hutagalung', 'Hutapea', 'Hutasoit',
        'Irawan', 'Iswahyudi', 'Kuswoyo', 'Januar', 'Jailani', 'Kurniawan',
        'Kusumo', 'Latupono', 'Lazuardi', 'Maheswara', 'Mahendra', 'Mustofa',
        'Mansur', 'Mandala', 'Megantara', 'Maulana', 'Maryadi', 'Mangunsong',
        'Manullang', 'Marpaung', 'Marbun', 'Narpati', 'Natsir', 'Nugroho',
        'Najmudin', 'Nashiruddin', 'Nainggolan', 'Nababan', 'Napitupulu',
        'Pangestu', 'Putra', 'Pranowo', 'Prabowo', 'Pratama', 'Prasetya',
        'Prasetyo', 'Pradana', 'Pradipta', 'Prakasa', 'Permadi', 'Prasasta',
        'Prayoga', 'Ramadan', 'Rajasa', 'Rajata', 'Saptono', 'Santoso',
        'Saputra', 'Saefullah', 'Setiawan', 'Suryono', 'Suwarno', 'Siregar',
        'Sihombing', 'Salahudin', 'Sihombing', 'Samosir', 'Saragih', 'Sihotang',
        'Simanjuntak', 'Sinaga', 'Simbolon', 'Sitompul', 'Sitorus', 'Sirait',
        'Siregar', 'Situmorang', 'Tampubolon', 'Thamrin', 'Tamba', 'Tarihoran',
        'Utama', 'Uwais', 'Wahyudin', 'Waluyo', 'Wibowo', 'Winarno', 'Wibisono',
        'Wijaya', 'Widodo', 'Wacana', 'Waskita', 'Wasita', 'Zulkarnain',
    )

    # From http://namafb.com/2010/08/12/top-1000-nama-populer-indonesia/
    # via
    # https://github.com/fzaninotto/faker/blob/master/src/Faker/Provider/id_ID/Person.php
    last_names_female = (
        'Agustina', 'Andriani', 'Anggraini', 'Aryani', 'Astuti',
        'Fujiati', 'Farida', 'Handayani', 'Hassanah', 'Hartati', 'Hasanah',
        'Haryanti', 'Hariyah', 'Hastuti', 'Halimah', 'Kusmawati', 'Kuswandari',
        'Laksmiwati', 'Laksita', 'Lestari', 'Lailasari', 'Mandasari',
        'Mardhiyah', 'Mayasari', 'Melani', 'Mulyani', 'Maryati', 'Nurdiyanti',
        'Novitasari', 'Nuraini', 'Nasyidah', 'Nasyiah', 'Namaga', 'Palastri',
        'Pudjiastuti', 'Puspasari', 'Puspita', 'Purwanti', 'Pratiwi',
        'Purnawati', 'Pertiwi', 'Permata', 'Prastuti', 'Padmasari', 'Rahmawati',
        'Rahayu', 'Riyanti', 'Rahimah', 'Suartini', 'Sudiati', 'Suryatmi',
        'Susanti', 'Safitri', 'Oktaviani', 'Utami', 'Usamah', 'Usada',
        'Uyainah', 'Yuniar', 'Yuliarti', 'Yulianti', 'Yolanda', 'Wahyuni',
        'Wijayanti', 'Widiastuti', 'Winarsih', 'Wulandari', 'Wastuti', 'Zulaika',
    )

    last_names = last_names_male + last_names_female

    prefixes_male = (
        'Dt.', 'R.', 'R.M.', 'Sutan', 'T.', 'Tgk.',

        # From http://id.wikipedia.org/wiki/Gelar_akademik
        # via
        # https://github.com/fzaninotto/faker/blob/master/src/Faker/Provider/id_ID/Person.php
        # plus noble titles
        'dr.', 'drg.', 'Dr.', 'Drs.', 'Ir.', 'H.', 'KH.',
    )

    prefixes_female = (
        'Cut', 'Puti', 'R.', 'R.A.', 'Tgk.',

        # From http://id.wikipedia.org/wiki/Gelar_akademik
        # via
        # https://github.com/fzaninotto/faker/blob/master/src/Faker/Provider/id_ID/Person.php
        # plus noble titles
        'dr.', 'drg.', 'Dr.', 'Drs.', 'Ir.' 'Hj.',
    )

    # From http://id.wikipedia.org/wiki/Gelar_akademik
    # via
    # https://github.com/fzaninotto/faker/blob/master/src/Faker/Provider/id_ID/Person.php
    suffixes = (
        'S.Ked', 'S.Gz', 'S.Pt', 'S.IP', 'S.E.I', 'S.E.', 'S.Kom', 'S.H.',
        'S.T.', 'S.Pd', 'S.Psi', 'S.I.Kom', 'S.Sos', 'S.Farm', 'M.M.', 'M.Kom.',
        'M.TI.', 'M.Pd', 'M.Farm', 'M.Ak',
    )



# coding=utf-8

from __future__ import unicode_literals
from .. import Provider as SsnProvider

"""
For more info on rijksregisternummer, see https://nl.wikipedia.org/wiki/Rijksregisternummer
Dutch/French only for now ...
"""


class Provider(SsnProvider):

    def ssn(self):
        """
        Returns a 11 digits Belgian SSN called "rijksregisternummer" as a string

        The first 6 digits represent the birthdate with (in order) year, month and day.
        The second group of 3 digits is represents a sequence number (order of birth).
        It is even for women and odd for men.
        For men the range starts at 1 and ends 997, for women 2 until 998.
        The third group of 2 digits is a checksum based on the previous 9 digits (modulo 97).
        Divide those 9 digits by 97, subtract the remainder from 97 and that's the result.
        For persons born in or after 2000, the 9 digit number needs to be proceeded by a 2
        (add 2000000000) before the division by 97.

        """
        # see http://nl.wikipedia.org/wiki/Burgerservicenummer (in Dutch)
        def _checksum(digits):
            res = 97 - (digits % 97)
            return res

        # Generate a date (random)
        mydate = self.generator.date()
        # Convert it to an int
        elms = mydate.split("-")
        # Adjust for year 2000 if necessary
        if elms[0][0] == '2':
            above = True
        else:
            above = False
        # Only keep the last 2 digits of the year
        elms[0] = elms[0][2:4]
        # Simulate the gender/sequence - should be 3 digits
        seq = self.generator.random_int(1, 998)
        # Right justify sequence and append to list
        seq_str = "{:0>3}".format(seq)
        elms.append(seq_str)
        # Now convert list to an integer so the checksum can be calculated
        date_as_int = int("".join(elms))
        if above:
            date_as_int += 2000000000
        # Generate checksum
        s = _checksum(date_as_int)
        s_rjust = "{:0>2}".format(s)
        # return result as a string
        elms.append(s_rjust)
        return "".join(elms)



# coding=utf-8

from __future__ import unicode_literals
from .. import Provider as SsnProvider
from math import ceil


class Provider(SsnProvider):

    def ssn(self):
        """
        Returns an Israeli identity number, known as Teudat Zehut ("tz").

        https://en.wikipedia.org/wiki/Israeli_identity_card
        """

        newID = str(self.generator.random.randrange(111111, 99999999))
        newID = newID.zfill(8)
        theSum = 0
        indexRange = [0, 2, 4, 6]
        for i in indexRange:
            digit = newID[i]
            num = int(digit)
            theSum = theSum + num
            num = int(newID[i + 1]) * 2
            if num > 9:
                num = int(str(num)[0]) + int(str(num)[1])
            theSum = theSum + num
        lastDigit = theSum % 10
        if lastDigit != 0:
            lastDigit = 10 - lastDigit

        return str(newID) + str(lastDigit)



# coding=utf-8
from __future__ import unicode_literals
from .. import BaseProvider


class Provider(BaseProvider):
    # Derived from KSH's FEOR'08
    jobs = (
        'Titkár(nő)',
        'Értékbecslő',
        'Közterület-felügyelő',
        'Építőmérnök',
        'Köszörűs',
        'Gépjármű- és motorkarbantartó',
        'Mezőgazdasági mérnök',
        'Számítógéphálózat- és rendszertechnikus',
        'Adósságbehajtó',
        'Fémöntőminta-készítő',
        'Gyümölcs- és zöldségfeldolgozó',
        'Telekommunikációs mérnök',
        'Könyv- és lapkiadó szerkesztője',
        'Geológus',
        'Manikűrös',
        'Energetikus',
        'Kézbesítő',
        'Kontroller',
        'Mentőtiszt',
        'Háztartási takarító és kisegítő',
        'Dekoratőr',
        'Tejfeldolgozó',
        'Gyógytornász',
        'Csomagkihordó',
        'Kádár',
        'Színész',
        'Anyaggazdálkodó',
        'Szoftverfejlesztő',
        'Adó- és illetékhivatali ügyintéző',
        'Utaskísérő',
        'Táj- és kertépítészmérnök',
        'Muzeológus',
        'Koreográfus',
        'Tetőfedő',
        'Telepőr',
        'Pedikűrös',
        'Fémfeldolgozó',
        'Intézményi takarító és kisegítő',
        'Irodai szakmai irányító',
        'Recepciós',
        'Gépíró, szövegszerkesztő',
        'Ifjúságsegítő',
        'Pap',
        'Adatbázis- és hálózati elemző',
        'Szoftver- és alkalmazásfejlesztő',
        'Burkoló',
        'Történész',
        'Intézményi takarító és kisegítő ',
        'Kohó- és anyagtechnikus',
        'Jogi asszisztens',
        'Tőzsde- és pénzügyi ügynök',
        'Varró',
        'Bolti pénztáros',
        'Kémikus',
        'Kőműves',
        'Szakorvos',
        'Elemző közgazdász',
        'Kézi mosó, vasaló',
        'Irattáros',
        'Földmérő és térinformatikus',
        'Vendéglős',
        'Élelmiszer-ipari mérnök',
        'Kisállattartó és -tenyésztő',
        'Szociológus',
        'Lakatos',
        'Pszichológus',
        'Utcaseprő',
        'Adatbázis-tervező és -üzemeltető',
        'Gyermekfelügyelő',
        'Metróvezető',
        'Háztartási alkalmazott',
        'Könyvelő',
        'Általános irodai adminisztrátor',
        'Épületasztalos',
        'Ékszerkészítő',
        'Üvegező',
        'Könyvtári, levéltári nyilvántartó',
        'Általános iskolai tanár, tanító',
        'Szemétgyűjtő',
        'Rendőr',
        'Orvosi laboratóriumi asszisztens',
        'Kubikos',
        'Adatrögzítő',
        'Informatikatanár',
        'Fizikus',
        'Vegyésztechnikus',
        'Hímző',
        'Ügynök',
        'Kalapos',
        'Egyéb művészetek tanára',
        'Zöldségtermesztő',
        'Dísznövény-, virág- és faiskolai kertész, csemetenevelő',
        'Csipkeverő',
        'Postai ügyfélkapcsolati foglalkozású',
        'Tolmács',
        'Kódoló',
        'Fa- és könnyűipari mérnök',
        'Szarvasmarha-, ló-, sertés-, juhtartó és -tenyésztő ',
        'Település- és közlekedéstervező mérnök',
        'Rendszergazda',
        'Állatorvosi asszisztens',
        'Újságíró',
        'Piaci, utcai étel- és italárus',
        'Néprajzkutató',
        'Vám- és pénzügyőr',
        'Hordár',
        'Webrendszer-technikus',
        'Hivatalsegéd',
        'Üzletpolitikai elemző',
        'Fogorvos',
        'Statisztikus',
        'Stukkózó',
        'Utazásszervező',
        'Épületbádogos',
        'Szociális gondozó',
        'Villamosipari technikus (elektronikai technikus)',
        'Iratkezelő',
        'Matróz',
        'Trolibuszvezető',
        'Banki pénztáros',
        'Szikvízkészítő',
        'Kovács',
        'Minőségbiztosítási mérnök',
        'Csillagász',
        'Író',
        'Könyvtáros',
        'Fényképész',
        'Bányászati technikus',
        'Üzletpolitikai elemző, szervező',
        'Jelnyelvi tolmács',
        'Alkalmazásprogramozó',
        'Cipőkészítő',
        'Drágakőcsiszoló',
        'Botanikus',
        'Járműtakarító',
        'Biztosítási ügynök',
        'Gépészmérnök',
        'Légiforgalmi irányító',
        'Üveggyártó',
        'Gumitermékgyártó',
        'Repülőgépmotor-karbantartó',
        'Építészmérnök',
        'Tűzoltó',
        'Könyvkötő',
        'Pultos',
        'Borász',
        'Gyógyszerész',
        'Kozmetikus',
        'Segédápoló',
        'Ápoló',
        'Fordító',
        'Munkavédelmi és üzembiztonsági foglalkozású',
        'Végrehajtó, adósságbehajtó',
        'Gyógyszertári asszisztens',
        'Szőrmefestő',
        'Bőrtermékkészítő',
        'Műsorszóró és audiovizuális technikus',
        'Kártevőirtó',
        'Rakodómunkás',
        'Szabásminta-készítő',
        'Hulladékosztályozó',
        'Erdő- és természetvédelmi mérnök',
        'Készlet- és anyagnyilvántartó',
        'Fogászati asszisztens',
        'Séf',
        'Könyvszakértő',
        'Bróker',
        'Áru- és divatbemutató',
        'Kölcsönző',
        'Épületgondnok',
        'Telekommunikációs technikus',
        'Környezetvédelmi technikus',
        'Házvezető',
        'Famegmunkáló',
        'Szállodai recepciós',
        'Kézi csomagoló',
        'Ötvös',
        'Csecsemő- és kisgyermeknevelő',
        'Kerékpár-karbantartó',
        'Operatőr',
        'Ügyvéd',
        'Szigetelő',
        'Fizioterápiás asszisztens',
        'Kereskedő',
        'Biológus',
        'Ruházati gép kezelője és gyártósor mellett dolgozó',
        'Szűcs',
        'Ügyféltájékoztató',
        'Gyógynövénytermesztő',
        'Lelkész',
        'Énekes',
        'Munka- és termelésszervező ',
        'Légiforgalmi irányítástechnikus',
        'Számítógép-hálózati elemző',
        'Szabó',
        'Szakács',
        'Növényorvos ',
        'Testőr',
        'Erdő- és természetvédelmi technikus',
        'Kőfaragó',
        'Bányászati szakmai irányító',
        'Régész',
        'Lakossági kérdező',
        'Számviteli ügyintéző',
        'Természetvédelmi őr',
        'Egyetemi, főiskolai oktató',
        'Óvodapedagógus',
        'Gyomírtó',
        'Növényvédelmi szakértő',
        'Védőnő',
        'Egészségügyi dokumentátor ',
        'Finommechanikai műszerész',
        'Műszaki rajzoló',
        'Demográfus',
        'Általános orvos',
        'Fedélzeti tiszt',
        'Vagyonőr',
        'Rendszerelemző',
        'Tímár',
        'Hajózómérnök',
        'Hálózat- és multimédia-fejlesztő',
        'Konyhai kisegítő',
        'Mozigépész',
        'Épületvillamossági szerelő',
        'Bionövény-termesztő',
        'Fogtechnikus',
        'Büntetés-végrehajtási őr',
        'Erdész',
        'Vízgazdálkodási gépkezelő',
        'Szerszámkészítő',
        'Vegyészmérnök',
        'Festő',
        'Iratkezelő, irattáros',
        'Légiforgalmi irányítástechnikai berendezések üzemeltetője',
        'Masszőr',
        'Zenetanár',
        'Zálogházi ügyintéző és pénzkölcsönző',
        'Jogtanácsos',
        'Tehergépkocsi-vezető',
        'Bolti eladó',
        'Pénzintézeti ügyintéző',
        'Növényorvosi asszisztens',
        'Fitnesz- és rekreációs program irányítója',
        'Zeneszerző',
        'Építményszerkezet-szerelő',
        'Vegyes profilú gazdálkodó',
        'Pultfeltöltő',
        'Képzőművész',
        'Végrehajtó',
        'Szerencsejáték-szervező',
        'Jegypénztáros',
        'Konyhafőnök',
        'Műtőssegéd',
        'Adótanácsadó',
        'Jogász',
        'Orvosi képalkotó diagnosztikai asszisztens',
        'Zoológus',
        'Látszerész',
        'Szállítási, szállítmányozási nyilvántartó',
        'Kárpitos',
        'Házi gondozó',
        'Táncművész',
        'Cipész',
        'Élelmiszer-ipari technikus',
        'Zenész',
        'Könyvelő (analitikus)',
        'Felvásárló',
        'Személyzeti és pályaválasztási szakértő',
        'Bányamérnök',
        'Pincér',
        'Mosodai gép kezelője',
        'Dietetikus',
        'Rendező',
        'Bognár',
        'Targoncavezető',
        'Hobbiállat-gondozó',
        'Segédrendező',
        'Marketing- és PR-ügyintéző',
        'Bőrdíszműves',
        'Darukezelő',
        'Hallás- és beszédterapeuta',
        'Konduktor',
        'Villamosmérnök (energetikai mérnök)',
        'Meteorológus',
        'Táplálkozási tanácsadó',
        'Cirkuszi előadóművész',
        'Húsfeldolgozó',
        'Vezető eladó',
        'Könyvvizsgáló',
        'Feldolgozóipari szakmai irányító',
        'Pedagógiai szakértő',
        'Telefonos értékesítési ügynök',
        'Villamosvezető',
        'Baromfitartó és -tenyésztő',
        'Politológus',
        'Mérőóra-leolvasó',
        'Egyéb növénytermesztési foglalkozású',
        'Méhész',
        'Felvonószerelő',
        'Személygépkocsi-vezető',
        'Textilműves',
        'Építő- és építésztechnikus',
        'Bőröndös',
        'Gipszkartonozó',
        'Kalauz',
        'Járművezető-oktató',
        'Bérelszámoló',
        'Bútorasztalos',
        'Villanyszerelő',
        'Kesztyűs',
        'Nyomdai előkészítő',
        'Mezőgazdasági technikus',
        'Szőlő-, gyümölcstermesztő',
        'Oktatási asszisztens',
        'Édesiparitermék-gyártó',
        'Fodrász',
        'Nyomdász',
        'Keramikus',
        'Általános egészségügyi asszisztens',
        'Ács',
        'Kereskedelmi ügyintéző',
        'Környezetfelmérő',
        'Kéményseprő',
        'Fotó- és mozgófilmlaboráns',
        'Statisztikai ügyintéző',
        'Szakképzett edző',
        'Fa- és könnyűipari technikus',
        'Múzeumi gyűjteménygondnok',
        'Árufeltöltő',
        'Idegenvezető',
        'Mozdonyvezető',
        'Kohó- és anyagmérnök',
        'Műköves',
        'Állatorvos',
        'Földmérő és térinformatikai technikus ',
        'Nyelvtanár',
        'Ügyész',
        'Sportoló',
        'Címfestő',
        'Nyelvész',
        'Gyógypedagógus',
        'Üzemanyagtöltő állomás kezelője',
        'Fémcsiszoló',
        'Kulturális szervező',
        'Lakberendező',
        'Grafikus és multimédia-tervező ',
        'Középiskolai tanár',
        'Cukrász',
        'Légijármű-vezető',
        'Sportszervező',
        'Parkolóőr',
        'Favágó',
        'Matematikus',
        'Pénzügyi elemző és befektetési tanácsadó',
        'Konferencia- és rendezvényszervező',
        'Faesztergályos',
        'Kályha- és kandallóépítő',
        'Közjegyző',
        'Festékszóró',
        'Statiszta',
        'Minőségbiztosítási technikus',
        'Épületszerkezet-tisztító',
        'Menetjegyellenőr',
        'Kereskedelmi tervező ',
        'Munkaerő-piaci szolgáltatási ügyintéző',
        'Adószakértő',
        'Hegesztő',
        'Gyorséttermi eladó',
        'Iparművész',
        'Díszítő',
        'Szociálpolitikus',
        'Gyártmány- és ruhatervező',
        'Ingatlanforgalmazási ügyintéző',
        'Kormányos',
        'Díszletező',
        'Segédszínész',
        'Levéltáros',
        'Robbantómester',
        'Villamosipari technikus (energetikai technikus)',
        'Ortopédiai eszközkészítő',
        'Gépésztechnikus',
        'Szociális segítő',
        'Pék',
        'Ipari alpinista',
        'Villamosmérnök (elektronikai mérnök)',
        'Személyi asszisztens',
        'Ablaktisztító',
        'Portás',
        'Filozófus',
        'Forgácsoló',
        'Bábművész',
        'Kárszakértő',
        'Humánpolitikai adminisztrátor',
        'Hangszerkészítő',
        'Társadalombiztosítási és segélyezési hatósági ügyintéző',
        'Optometrista',
        'Szántóföldinövény-termesztő',
        'Ingatlanügynök',
        'Nyomozó',
        'Egyéb, máshova nem sorolható technikus',
        'Vezető takarító',
        'Autóbuszvezető',
        'Kárbecslő',
        'Piaci árus',
        'Bíró',
        'Általános iskolai tanár',
        'Szerszámköszörűs',
        'Építőipari szakmai irányító')

    def job(self):
        return self.random_element(self.jobs)



# -*- coding: utf-8 -*-
from __future__ import unicode_literals
from .. import Provider as CompanyProvider


class Provider(CompanyProvider):
    formats = ["{{company_prefix}}{{company_suffix}}", ]

    company_prefixes = ["超艺", "和泰", "九方", "鑫博腾飞", "戴硕电子", "济南亿次元",
                        "海创", "创联世纪", "凌云", "泰麒麟", "彩虹", "兰金电子",
                        "晖来计算机", "天益", "恒聪百汇", "菊风公司", "惠派国际公司",
                        "创汇", "思优", "时空盒数字", "易动力", "飞海科技", "华泰通安",
                        "盟新", "商软冠联", "图龙信息", "易动力", "华远软件", "创亿",
                        "时刻", "开发区世创", "明腾", "良诺", "天开", "毕博诚", "快讯",
                        "凌颖信息", "黄石金承", "恩悌", "雨林木风计算机", "双敏电子",
                        "维旺明", "网新恒天", "数字100", "飞利信", "立信电子", "联通时科",
                        "中建创业", "新格林耐特", "新宇龙信息", "浙大万朋", "MBP软件",
                        "昂歌信息", "万迅电脑", "方正科技", "联软", "七喜", "南康", "银嘉",
                        "巨奥", "佳禾", "国讯", "信诚致远", "浦华众城", "迪摩", "太极",
                        "群英", "合联电子", "同兴万点", "襄樊地球村", "精芯", "艾提科信",
                        "昊嘉", "鸿睿思博", "四通", "富罳", "商软冠联", "诺依曼软件",
                        "东方峻景", "华成育卓", "趋势", "维涛", "通际名联"]
    company_suffixes = [n + "有限公司" for n in ["科技", "网络", "信息", "传媒"]]

    def company_prefix(self):
        return self.random_element(self.company_prefixes)



from __future__ import unicode_literals
from collections import OrderedDict

from ..en import Provider as AddressProvider


class Provider(AddressProvider):
    city_prefixes = ('North', 'East', 'West', 'South', 'New', 'Lake', 'Port')
    city_suffixes = (
        'town',
        'ton',
        'land',
        'ville',
        'berg',
        'burgh',
        'borough',
        'bury',
        'view',
        'port',
        'mouth',
        'stad',
        'furt',
        'chester',
        'mouth',
        'fort',
        'haven',
        'side',
        'shire',
    )
    building_number_formats = ('#', '##', '###')
    street_suffixes = (
        'alley',
        'avenue',
        'branch',
        'bridge',
        'brook',
        'brooks',
        'burg',
        'burgs',
        'bypass',
        'camp',
        'canyon',
        'cape',
        'causeway',
        'center',
        'centers',
        'circle',
        'circles',
        'cliff',
        'cliffs',
        'club',
        'common',
        'corner',
        'corners',
        'course',
        'court',
        'courts',
        'cove',
        'coves',
        'creek',
        'crescent',
        'crest',
        'crossing',
        'crossroad',
        'curve',
        'dale',
        'dam',
        'divide',
        'drive',
        'drive',
        'drives',
        'estate',
        'estates',
        'expressway',
        'extension',
        'extensions',
        'fall',
        'falls',
        'ferry',
        'field',
        'fields',
        'flat',
        'flats',
        'ford',
        'fords',
        'forest',
        'forge',
        'forges',
        'fork',
        'forks',
        'fort',
        'freeway',
        'garden',
        'gardens',
        'gateway',
        'glen',
        'glens',
        'green',
        'greens',
        'grove',
        'groves',
        'harbor',
        'harbors',
        'haven',
        'heights',
        'highway',
        'hill',
        'hills',
        'hollow',
        'inlet',
        'inlet',
        'island',
        'island',
        'islands',
        'islands',
        'isle',
        'isle',
        'junction',
        'junctions',
        'key',
        'keys',
        'knoll',
        'knolls',
        'lake',
        'lakes',
        'land',
        'landing',
        'lane',
        'light',
        'lights',
        'loaf',
        'lock',
        'locks',
        'locks',
        'lodge',
        'lodge',
        'loop',
        'mall',
        'manor',
        'manors',
        'meadow',
        'meadows',
        'mews',
        'mill',
        'mills',
        'mission',
        'mission',
        'motorway',
        'mount',
        'mountain',
        'mountain',
        'mountains',
        'mountains',
        'neck',
        'orchard',
        'oval',
        'overpass',
        'park',
        'parks',
        'parkway',
        'parkways',
        'pass',
        'passage',
        'path',
        'pike',
        'pine',
        'pines',
        'place',
        'plain',
        'plains',
        'plains',
        'plaza',
        'plaza',
        'point',
        'points',
        'port',
        'port',
        'ports',
        'ports',
        'prairie',
        'prairie',
        'radial',
        'ramp',
        'ranch',
        'rapid',
        'rapids',
        'rest',
        'ridge',
        'ridges',
        'river',
        'road',
        'road',
        'roads',
        'roads',
        'route',
        'row',
        'rue',
        'run',
        'shoal',
        'shoals',
        'shore',
        'shores',
        'skyway',
        'spring',
        'springs',
        'springs',
        'spur',
        'spurs',
        'square',
        'square',
        'squares',
        'squares',
        'station',
        'station',
        'stravenue',
        'stravenue',
        'stream',
        'stream',
        'street',
        'street',
        'streets',
        'summit',
        'summit',
        'terrace',
        'throughway',
        'trace',
        'track',
        'trafficway',
        'trail',
        'trail',
        'tunnel',
        'tunnel',
        'turnpike',
        'turnpike',
        'underpass',
        'union',
        'unions',
        'valley',
        'valleys',
        'via',
        'viaduct',
        'view',
        'views',
        'village',
        'village',
        'villages',
        'ville',
        'vista',
        'vista',
        'walk',
        'walks',
        'wall',
        'way',
        'ways',
        'well',
        'wells')

    POSTAL_ZONES = (
        'AB', 'AL', 'B', 'BA', 'BB', 'BD', 'BH', 'BL', 'BN', 'BR',
        'BS', 'BT', 'CA', 'CB', 'CF', 'CH', 'CM', 'CO', 'CR', 'CT',
        'CV', 'CW', 'DA', 'DD', 'DE', 'DG', 'DH', 'DL', 'DN', 'DT',
        'DY', 'E', 'EC', 'EH', 'EN', 'EX', 'FK', 'FY', 'G', 'GL',
        'GY', 'GU', 'HA', 'HD', 'HG', 'HP', 'HR', 'HS', 'HU', 'HX',
        'IG', 'IM', 'IP', 'IV', 'JE', 'KA', 'KT', 'KW', 'KY', 'L',
        'LA', 'LD', 'LE', 'LL', 'LN', 'LS', 'LU', 'M', 'ME', 'MK',
        'ML', 'N', 'NE', 'NG', 'NN', 'NP', 'NR', 'NW', 'OL', 'OX',
        'PA', 'PE', 'PH', 'PL', 'PO', 'PR', 'RG', 'RH', 'RM', 'S',
        'SA', 'SE', 'SG', 'SK', 'SL', 'SM', 'SN', 'SO', 'SP', 'SR',
        'SS', 'ST', 'SW', 'SY', 'TA', 'TD', 'TF', 'TN', 'TQ', 'TR',
        'TS', 'TW', 'UB', 'W', 'WA', 'WC', 'WD', 'WF', 'WN', 'WR',
        'WS', 'WV', 'YO', 'ZE'
    )

    POSTAL_ZONES_ONE_CHAR = [zone for zone in POSTAL_ZONES if len(zone) == 1]
    POSTAL_ZONES_TWO_CHARS = [zone for zone in POSTAL_ZONES if len(zone) == 2]

    postcode_formats = (
        'AN NEE',
        'ANN NEE',
        'PN NEE',
        'PNN NEE',
        'ANC NEE',
        'PND NEE',
    )

    _postcode_sets = OrderedDict((
        (' ', ' '),
        ('N', [str(i) for i in range(0, 10)]),
        ('A', POSTAL_ZONES_ONE_CHAR),
        ('B', 'ABCDEFGHKLMNOPQRSTUVWXY'),
        ('C', 'ABCDEFGHJKSTUW'),
        ('D', 'ABEHMNPRVWXY'),
        ('E', 'ABDEFGHJLNPQRSTUWXYZ'),
        ('P', POSTAL_ZONES_TWO_CHARS),
    ))

    city_formats = (
        '{{city_prefix}} {{first_name}}{{city_suffix}}',
        '{{city_prefix}} {{first_name}}',
        '{{first_name}}{{city_suffix}}',
        '{{last_name}}{{city_suffix}}',
    )
    street_name_formats = (
        '{{first_name}} {{street_suffix}}',
        '{{last_name}} {{street_suffix}}'
    )
    street_address_formats = (
        '{{building_number}} {{street_name}}',
        '{{secondary_address}}\n{{street_name}}',
    )
    address_formats = (
        "{{street_address}}\n{{city}}\n{{postcode}}",
    )
    secondary_address_formats = (
        'Flat #', 'Flat ##', 'Flat ##?', 'Studio #', 'Studio ##', 'Studio ##?')

    def postcode(self):
        """
        See http://web.archive.org/web/20090930140939/http://www.govtalk.gov.uk/gdsc/html/noframes/PostCode-2-1-Release.htm
        """
        postcode = ''
        pattern = self.random_element(self.postcode_formats)
        for placeholder in pattern:
            postcode += self.random_element(self._postcode_sets[placeholder])
        return postcode

    def city_prefix(self):
        return self.random_element(self.city_prefixes)

    def secondary_address(self):
        return self.bothify(self.random_element(self.secondary_address_formats))



# coding=utf-8
from __future__ import unicode_literals
from .. import Provider as SsnProvider

def checksum(sin):
    """
    Determine validity of a Canadian Social Insurance Number.
    Validation is performed using a modified Luhn Algorithm.  To check
    the Every second digit of the SIN is doubled and the result is
    summed.  If the result is a multiple of ten, the Social Insurance
    Number is considered valid.

    https://en.wikipedia.org/wiki/Social_Insurance_Number
    """

    # Remove spaces and create a list of digits.
    checksumCollection = list(sin.replace(' ', ''))
    checksumCollection = [int(i) for i in checksumCollection]

    # Discard the last digit, we will be calculating it later.
    checksumCollection[-1] = 0

    # Iterate over the provided SIN and double every second digit.
    # In the case that doubling that digit results in a two-digit
    # number, then add the two digits together and keep that sum.

    for i in range(1, len(checksumCollection), 2):
        result = checksumCollection[i] * 2
        if result < 10:
            checksumCollection[i] = result
        else:
            checksumCollection[i] = result - 10 + 1

    # The appropriate checksum digit is the value that, when summed
    # with the first eight values, results in a value divisible by 10

    check_digit = 10 - (sum(checksumCollection) % 10)
    check_digit = (0 if check_digit == 10 else check_digit)

    return check_digit

class Provider(SsnProvider):

    # In order to create a valid SIN we need to provide a number that 
    # passes a simple modified Luhn Algorithm checksum. 
    # 
    # This function reverses the checksum steps to create a random
    # valid nine-digit Canadian SIN (Social Insurance Number) in the
    # format '### ### ###'.
    def ssn(self):

        # Create an array of 8 elements initialized randomly.
        digits = self.generator.random.sample(range(9), 8)

        # The final step of the validation requires that all of the 
        # digits sum to a multiple of 10. First, sum the first 8 and
        # set the 9th to the value that results in a multiple of 10.
        check_digit = 10 - (sum(digits) % 10)
        check_digit = (0 if check_digit == 10 else check_digit)

        digits.append(check_digit)

        # digits is now the digital root of the number we want 
        # multiplied by the magic number 121 212 121. The next step is
        # to reverse the multiplication which occurred on every other
        # element.
        for i in range(1, len(digits), 2):
            if digits[i] % 2 == 0:
                digits[i] = (digits[i] // 2)
            else:
                digits[i] = (digits[i] + 9) // 2

        # Build the resulting SIN string.
        sin = ""
        for i in range(0, len(digits)):
            sin += str(digits[i])
            # Add a space to make it conform to Canadian formatting.
            if i in (2,5):
                sin += " "

        # Finally return our random but valid SIN.
        return sin



# coding=utf-8
from __future__ import unicode_literals
from .. import Provider as InternetProvider


class Provider(InternetProvider):

    free_email_domains = (
        'gmail.com', 'hotmail.com', 'yahoo.com', 'outlook.com',
        'bih.net.ba', 'tel.net.ba',
    )

    tlds = ('ba', 'com.ba', 'org.ba', 'net.ba', 'gov.ba', 'edu.ba', 'unsa.ba')

    replacements = (
        ('č', 'c'), ('Č', 'C'),
        ('ć', 'c'), ('Ć', 'C'),
        ('đ', 'dj'), ('Đ', 'Dj'),
        ('š', 's'), ('Š', 'S'),
        ('ž', 'z'), ('Ž', 'Z')
    )



# coding=utf-8
from __future__ import unicode_literals
from .. import Provider as InternetProvider


class Provider(InternetProvider):
    safe_email_tlds = ('com', 'net', 'br', 'br')
    free_email_domains = (
        'gmail.com',
        'hotmail.com',
        'yahoo.com.br',
        'uol.com.br',
        'bol.com.br',
        'ig.com.br')
    tlds = ('com', 'com', 'com', 'net', 'org', 'br', 'br', 'br')



# coding=utf-8
from __future__ import unicode_literals
from .. import Provider as PersonProvider


class Provider(PersonProvider):
    formats_female = (
        '{{first_name_female}} {{last_name}}',
        '{{first_name_female}} {{first_name_female}} {{last_name}}',
        '{{first_name_female}} {{last_name}}',
        '{{first_name_female}} {{first_name_female}} {{last_name}} {{last_name}}',
        '{{first_name_female}} {{last_name}} {{last_name}}',
        '{{prefix_female}} {{first_name_female}} {{first_name_female}} {{last_name}}',
        '{{prefix_female}} {{first_name_female}} {{first_name_female}} {{last_name}} {{last_name}}',
        '{{prefix_female}} {{first_name_female}} {{last_name}} {{last_name}}')

    formats_male = (
        '{{first_name_male}} {{last_name}}',
        '{{first_name_male}} {{first_name_male}} {{last_name}}',
        '{{first_name_male}} {{last_name}}',
        '{{first_name_male}} {{first_name_male}} {{last_name}} {{last_name}}',
        '{{first_name_male}} {{last_name}}',
        '{{prefix_male}} {{first_name_male}} {{last_name}}',
        '{{first_name_male}} {{last_name}}',
        '{{prefix_male}} {{first_name_male}} {{first_name_male}} {{last_name}}'
    )

    formats = formats_male + formats_female

    first_names_female = ('Abiye', 'Acarkan', 'Adal', 'Adila', 'Adviye',
                          'Afife', 'Ahter', 'Akay', 'Akgüneş', 'Akise', 'Akmaral', 'Aksoy',
                          'Akyıldız', 'Alabezek', 'Alaz', 'Algış', 'Alize', 'Almast', 'Alsoy',
                          'Altınbike', 'Altınçiçek', 'Alışık', 'Amre', 'Anargül', 'Anka', 'Aral',
                          'Armahan', 'Arziye', 'Arıpınar', 'Asiman', 'Asliye', 'Asu', 'Atanur',
                          'Atiyye', 'Avunç', 'Ayasun', 'Aybet', 'Aycagül', 'Aydar', 'Ayduru',
                          'Aygönenç', 'Ayhan', 'Aykut', 'Aylil', 'Aynilhayat', 'Aynımah',
                          'Aysema', 'Aysevim', 'Aysuna', 'Ayten', 'Aytöz', 'Ayyaruk', 'Ayçan',
                          'Ayülker', 'Ayşeana', 'Ayşenur', 'Azade', 'Azize', 'Açılay', 'Ağbegim',
                          'Aşhan', 'Badegül', 'Bahtinur', 'Balca', 'Ballı', 'Banü', 'Basriye',
                          'Bağdat', 'Bediriye', 'Begim', 'Behiza', 'Belgizar', 'Belkize', 'Benek',
                          'Benice', 'Beray', 'Bergen', 'Beriye', 'Berrin', 'Besey', 'Beste',
                          'Beyhatun', 'Bezek', 'Bidayet', 'Bilay', 'Bilginur', 'Bilkay', 'Binay',
                          'Birben', 'Birgül', 'Birsan', 'Bitül', 'Burcuhan', 'Buşra', 'Büreyre',
                          'Büşranur', 'Canan', 'Canfeza', 'Cannur', 'Canseven', 'Canur', 'Cedide',
                          'Cemiyle', 'Cevale', 'Ceyhun', 'Cihan', 'Cuheyna', 'Damlanur', 'Deha',
                          'Deniz', 'Deryanur', 'Değer', 'Dilara', 'Dilcan', 'Dilfeza', 'Dilhuş',
                          'Dilsitan', 'Dilşat', 'Divan', 'Doğannur', 'Duha', 'Durgadin',
                          'Dursadiye', 'Duyguhan', 'Döner', 'Dürrüşehvar', 'Ecegül', 'Edaviye',
                          'Efil', 'Egenur', 'Elamiye', 'Elgin', 'Elifnur', 'Elvan', 'Emal',
                          'Emine.', 'Emiş', 'Enfes', 'Erbay', 'Erem', 'Ergül', 'Eriş', 'Ervaniye',
                          'Esengün', 'Esmanperi', 'Esna', 'Evde', 'Evrim', 'Ezgin', 'Eşim',
                          'Fadile', 'Fadıla', 'Faize', 'Fatigül', 'Fatinur', 'Fatmanur', 'Fayize',
                          'Feden', 'Fehmiye', 'Ferahdiba', 'Feraye', 'Ferhan', 'Ferinaz',
                          'Fermuta', 'Feryas', 'Feyha', 'Feyzin', 'Fidaye', 'Fildan', 'Firdevis',
                          'Fitnat', 'Fügen', 'Gabel', 'Ganiye', 'Gelengül', 'Gilman', 'Goncafer',
                          'Gök', 'Gökperi', 'Gökçe', 'Göli', 'Görsev', 'Gözem', 'Gül', 'Gülay',
                          'Gülbani', 'Gülbeyan', 'Gülbiye', 'Gülcegün', 'Güldam', 'Gülder',
                          'Güldünya', 'Gülenay', 'Güler', 'Gülev', 'Gülfari', 'Gülfeza', 'Gülgen',
                          'Gülgüzel', 'Gülhisar', 'Gülinaz', 'Gülkadın', 'Güllühan', 'Gülmisal',
                          'Gülnaziye', 'Gülper', 'Gülsalın', 'Gülselin', 'Gülseren', 'Gülsevil',
                          'Gülsiye', 'Gülsü', 'Gülter', 'Gülzadiye', 'Gülçe', 'Gülözge', 'Gülüs',
                          'Gülşa', 'Gülşeref', 'Günar', 'Günebakan', 'Güngören', 'Günsel',
                          'Günver', 'Gürcüye', 'Gürten', 'Güverçin', 'Güzey', 'Habibe', 'Hacile',
                          'Hadrey', 'Hafıza', 'Halenur', 'Haliye', 'Hamiyet', 'Hanbiken', 'Hanim',
                          'Hansultan', 'Harbinaz', 'Hasgül', 'Hasret', 'Hatin', 'Havali', 'Havse',
                          'Hayel', 'Hayrünnisa', 'Hazine', 'Hekime', 'Henife', 'Heva', 'Hezniye',
                          'Hilayda', 'Hinet', 'Hoşkadem', 'Huban', 'Hurican', 'Hurşide', 'Hüda',
                          'Hümeyra', 'Hürmet', 'Hürüyet', 'Hüsnühâl', 'Ildız', 'Irıs', 'Işin',
                          'Işın', 'Jaruthip', 'Kader', 'Kadınana', 'Kandef', 'Kardelen', 'Kaver',
                          'Kefser', 'Kerime', 'Kezban', 'Kifaye', 'Kitan', 'Koncagül', 'Kumral',
                          'Kutgün', 'Kutun', 'Kâzime', 'Kübran', 'Kısmet', 'Laika', 'Laze',
                          'Lerze', 'Leyli', 'Lezize', 'Limon', 'Lâle', 'Lüfen', 'Macide',
                          'Mahigül', 'Mahnaz', 'Mahter', 'Maksüde', 'Masume', 'Maynur', 'Maşide',
                          'Mecide', 'Mefharet', 'Mehdiye', 'Mehrigül', 'Melaha', 'Meleknur',
                          'Melikkan', 'Melûl', 'Menfeat', 'Menişan', 'Merba', 'Merim', 'Merva',
                          'Meryeme', 'Mesude', 'Meveddet', 'Mevlüdiye', 'Meyhanim', 'Mezide',
                          'Mihrab', 'Mihriye', 'Minibe', 'Miray', 'Misra', 'Miyesser', 'Muarra',
                          'Mufide', 'Muhiye', 'Mujde', 'Mukbile', 'Musaffa', 'Muvahhide',
                          'Mübetcel', 'Mücevher', 'Müferrih', 'Müjde', 'Mükrüme', 'Mümtaze',
                          'Münezzer', 'Müret', 'Müsemma', 'Müveddet', 'Müğber', 'Müşüre', 'Nades',
                          'Nafile', 'Naide', 'Nalân', 'Narhanim', 'Nasiba', 'Natalia', 'Naz',
                          'Nazende', 'Nazi', 'Nazimet', 'Nazlihan', 'Nazıdil', 'Nebiha',
                          'Necilal', 'Necva', 'Nefaret', 'Nefiye', 'Nejdet', 'Neptün', 'Neriban',
                          'Nesfe', 'Neslinur', 'Neval', 'Nevgin', 'Nevise', 'Nevsale', 'Neyran',
                          'Nezengül', 'Nezize', 'Neşrin', 'Nihan', 'Nilcan', 'Nili', 'Nirgül',
                          'Niğmet', 'Nura', 'Nurbanu', 'Nurda', 'Nurdeniz', 'Nurey', 'Nurgil',
                          'Nurhayet', 'Nuriyet', 'Nurmelek', 'Nurseda', 'Nurser', 'Nursim',
                          'Nurtaç', 'Nurveren', 'Nurşan', 'Nüdret', 'Nürice', 'Oguş', 'Oluş',
                          'Orçin', 'Paksu', 'Paye', 'Pekkan', 'Pembesin', 'Peren', 'Perinur',
                          'Permun', 'Pesent', 'Piran', 'Pürçek', 'Rabbiye', 'Rafia', 'Rahiye',
                          'Rakide', 'Rana', 'Rayla', 'Rebihat', 'Refet', 'Rehime', 'Rengül',
                          'Revza', 'Rezin', 'Risalet', 'Rojnu', 'Ruhide', 'Ruhugül', 'Rumeysa',
                          'Rümeysa', 'Rıfkıye', 'Sabihe', 'Sabır', 'Sadeti', 'Sadiye', 'Safinaz',
                          'Safura', 'Sahil', 'Saire', 'Salimet', 'Samahat', 'Sanavber', 'Sanur',
                          'Sarya', 'Satıa', 'Saygın', 'Saçı', 'Sebigül', 'Seblâ', 'Sedife',
                          'Sefer', 'Sehel', 'Sejda', 'Selcen', 'Selime', 'Selmin', 'Selvi',
                          'Selçuk', 'Semat', 'Semine', 'Semrin', 'Seniha', 'Serda', 'Serfinaz',
                          'Serma', 'Sernur', 'Servinaz', 'Sevcan', 'Sevdinar', 'Sevgen',
                          'Sevginur', 'Sevican', 'Sevim', 'Sevla', 'Sevsevil', 'Seyhan',
                          'Seyyide', 'Sezen', 'Seçgül', 'Sidar', 'Silanur', 'Simber', 'Simten',
                          'Sirap', 'Siti', 'Solma', 'Sonnur', 'Soykan', 'Subutiye', 'Sultane',
                          'Sunay', 'Susam', 'Söyler', 'Süheyda', 'Süleyla', 'Sümerya', 'Süner',
                          'Süsen', 'Süzer', 'Sırriye', 'Tagangül', 'Talibe', 'Tan', 'Tangül',
                          'Tanses', 'Tanyu', 'Tasvir', 'Tayyibe', 'Taçnur', 'Teknaz', 'Temime',
                          'Tercan', 'Teybet', 'Ticen', 'Tomurcuk', 'Tule', 'Turcein', 'Tutkucan',
                          'Tuğçe', 'Tülin', 'Türcan', 'Türknur', 'Tüzenur', 'Ufukay', 'Ummahani',
                          'Umuşan', 'Uyanser', 'Uğur', 'Vacibe', 'Varlık', 'Vecide', 'Vefia',
                          'Verde', 'Vezrife', 'Vildane', 'Yahşi', 'Yalın', 'Yasemen', 'Yazgül',
                          'Yaşar', 'Yekbun', 'Yepelek', 'Yeşil', 'Yosma', 'Yurdaser', 'Yurtseven',
                          'Yücel', 'Yıldız', 'Zahfer', 'Zaliha', 'Zebirce', 'Zehranur', 'Zelha',
                          'Zemzem', 'Zerafet', 'Zeride', 'Zevlüde', 'Zeyno', 'Zilfa', 'Zinnure',
                          'Zubeyde', 'Zöhrehan', 'Züheyla', 'Zülbiye', 'Zülfüye', 'Zümre',
                          'Âlemşah', 'Çalım', 'Çağlar', 'Çevregül', 'Çilga', 'Çisem', 'Çolpan',
                          'Ömriye', 'Öncel', 'Örfiye', 'Övün', 'Özay', 'Özbilge', 'Özdeş', 'Özge',
                          'Özgün', 'Özlem', 'Özpetek', 'Özyurt', 'Üge', 'Ülke', 'Ülküm',
                          'Ümmahan', 'Ümmühan', 'Ümray', 'Ünal', 'Ünsever', 'Ürper', 'Üçgül',
                          'İde', 'İhsan', 'İklim', 'İldeş', 'İlkbahar', 'İlklima', 'İlper',
                          'İmge', 'İmrihan', 'İncifir', 'İnsaf', 'İrfan', 'İslime', 'İsra',
                          'İzel', 'İçimbike', 'Şadıman', 'Şahdiye', 'Şahinder', 'Şahnuray',
                          'Şahıgül', 'Şamiha', 'Şayan', 'Şazime', 'Şefiye', 'Şehreban', 'Şehza',
                          'Şelâle', 'Şemsinisa', 'Şendoğan', 'Şennur', 'Şeref', 'Şerman',
                          'Şevketfeza', 'Şeyda', 'Şilan', 'Şirivan', 'Şöhret', 'Şüküfe'

                          )

    first_names_male = ('Abdiş', 'Abdulbekir', 'Abdulgazi', 'Abdulkadir',
                        'Abdulmenaf', 'Abdulsemet', 'Abdurrahman', 'Abdülahat', 'Abdülcemal',
                        'Abdülhadi', 'Abdülkerim', 'Abdülsamed', 'Abdürreşit', 'Abid', 'Abuzar',
                        'Acar', 'Aclan', 'Adak', 'Adasal', 'Adlan', 'Adıgün', 'Afer', 'Ahat',
                        'Ahsen', 'Akalan', 'Akar', 'Akatay', 'Akbaş', 'Akboğa', 'Akcivan',
                        'Akdora', 'Akdurmuş', 'Akgöl', 'Akif', 'Akkerman', 'Akmaner', 'Aksay',
                        'Aksöğüt', 'Aktemür', 'Akver', 'Akçabay', 'Akçasu', 'Aköz', 'Akınal',
                        'Alaaddin', 'Alaeddin', 'Alanalp', 'Alattin', 'Alcan', 'Alexandru',
                        'Aliabbas', 'Aliihsan', 'Aliseydi', 'Alkor', 'Almus', 'Alparslan',
                        'Alpcan', 'Alpin', 'Alpsü', 'Alsoy', 'Altoğan', 'Altuğ', 'Altınkaya',
                        'Altınışın', 'Amaç', 'Andiç', 'Annak', 'Apaydın', 'Aran', 'Arcan',
                        'Argu', 'Arifcan', 'Arkut', 'Arpağ', 'Artan', 'Aru', 'Arıel', 'Arıkol',
                        'Arısoy', 'Asalet', 'Aslanhan', 'Asım', 'Atagün', 'Atalay', 'Atasagun',
                        'Atatöre', 'Atgun', 'Atilhan', 'Atnan', 'Atılgan', 'Avşin', 'Ayaydın',
                        'Aybora', 'Aydinç', 'Aydınbey', 'Aygutalp', 'Aykutalp', 'Aypar',
                        'Aysoy', 'Aytek', 'Aytuna', 'Ayvas', 'Ayşan', 'Azettin', 'Açıkel',
                        'Ağakişi', 'Ağmur', 'Aşir', 'Baba', 'Bahaddin', 'Bahittin', 'Baki',
                        'Balatekin', 'Bali', 'Baltaş', 'Barak', 'Bariş', 'Barsen', 'Barışcan',
                        'Basım', 'Baturay', 'Batırhan', 'Baydu', 'Baykan', 'Bayman', 'Bayruhan',
                        'Baytal', 'Bayzettin', 'Bağdaş', 'Başay', 'Başhan', 'Başok', 'Bedi',
                        'Bedri', 'Behrem', 'Bekbay', 'Bektaşi', 'Bellisan', 'Bengibay', 'Benol',
                        'Beren', 'Berkal', 'Berki', 'Berksay', 'Berran', 'Besin', 'Beyda',
                        'Beyler', 'Beyzade', 'Bican', 'Bilender', 'Bilgen', 'Bilgütay',
                        'Biltaş', 'Binbaşar', 'Binışık', 'Birgit', 'Birsen', 'Bişar', 'Borahan',
                        'Borataş', 'Boynak', 'Bozbağ', 'Bozerk', 'Boztaş', 'Boğatimur',
                        'Buhari', 'Bulunç', 'Burakhan', 'Burç', 'Buyrukhan', 'Börteçin',
                        'Büget', 'Bünyamün', 'Cabir', 'Canal', 'Canberk', 'Candeniz', 'Cangür',
                        'Cannur', 'Cansin', 'Cantez', 'Cavit', 'Cebesoy', 'Celilay',
                        'Cemalettin', 'Cenan', 'Cercis', 'Cevheri', 'Cezayir', 'Cihandide',
                        'Cindoruk', 'Coşkun', 'Cuman', 'Cüneyit', 'Dalan', 'Dalkılıç', 'Danış',
                        'Dayar', 'Dağistan', 'Delil', 'Demirbüken', 'Demiriz', 'Demirok',
                        'Demiryürek', 'Denizalp', 'Denkel', 'Derkay', 'Deviner', 'Değmeer',
                        'Diken', 'Dilder', 'Dincer', 'Dinçkol', 'Dinçsü', 'Dirican', 'Dirlik',
                        'Dolun', 'Dorukhan', 'Doğanalp', 'Doğanşah', 'Doğuhan', 'Duracan',
                        'Durdali', 'Durmuşali', 'Duruk', 'Duruöz', 'Dölensoy', 'Dündaralp',
                        'Eba', 'Ebuakil', 'Ecemiş', 'Edgübay', 'Efe', 'Eflâtun', 'Efser',
                        'Ekber', 'Ekmel', 'Elhan', 'Elnur', 'Elöve', 'Emin', 'Emirşan',
                        'Emrullah', 'Enes', 'Enginiz', 'Ensari', 'Eral', 'Eraycan', 'Erbil',
                        'Ercihan', 'Erdemer', 'Erdibay', 'Erdogan', 'Erdursun', 'Erenalp',
                        'Erensoy', 'Ergener', 'Erginel', 'Ergönül', 'Ergün', 'Erik', 'Erinçer',
                        'Erkan', 'Erkinel', 'Erksoy', 'Erkılıç', 'Ermutlu', 'Eroğul', 'Ersel',
                        'Erseç', 'Ertan', 'Erten', 'Ertuncay', 'Ertün', 'Eryıldız', 'Eröz',
                        'Erşat', 'Esenbay', 'Esentürk', 'Eskinalp', 'Evcimen', 'Evrimer',
                        'Eyyüp', 'Ezgütekin', 'Eşref', 'Fahrullah', 'Fami', 'Fatih', 'Fazul',
                        'Fehim', 'Fenni', 'Ferat', 'Feremez', 'Ferihan', 'Fersan', 'Ferzi',
                        'Fetullah', 'Feyruz', 'Feza', 'Filit', 'Fuzuli', 'Galip', 'Gazel',
                        'Gencaslan', 'Gençay', 'Geray', 'Ginyas', 'Giz', 'Gökay', 'Gökbudun',
                        'Göken', 'Göknur', 'Göksev', 'Gökten', 'Gökçebalan', 'Gökçil', 'Gönen',
                        'Görgünay', 'Görklü', 'Gözel', 'Gücal', 'Gülağa', 'Gülel', 'Güleğen',
                        'Gülşahin', 'Gümüştekin', 'Günaydin', 'Günden', 'Gündüzalp', 'Güneri',
                        'Güngördü', 'Günkurt', 'Günser', 'Günver', 'Günşen', 'Gürarda',
                        'Gürelcem', 'Gürsal', 'Güçal', 'Güçlüer', 'Güçyeter', 'Haciali',
                        'Hakikat', 'Halidun', 'Haluk', 'Hami', 'Hanedan', 'Hariz', 'Hasbek',
                        'Hatem', 'Hayali', 'Hayret', 'Hazrat', 'Hekmet', 'Heyvetullah', 'Hidir',
                        'Hindal', 'Hiçsönmez', 'Hudavent', 'Hunalp', 'Huzuri', 'Hükümdar',
                        'Hürdoğan', 'Hüryaşar', 'Hüsmen', 'Hıfzullah', 'Idık', 'Ilgı', 'Ismık',
                        'Işıkay', 'Işıman', 'Jankat', 'Kader', 'Kahir', 'Kalgay', 'Kamar',
                        'Kanak', 'Kanpulat', 'Kapagan', 'Karabaş', 'Karaca', 'Karaer',
                        'Karakucak', 'Karanbay', 'Karataş', 'Karcan', 'Karlukhan', 'Kasim',
                        'Kavurt', 'Kayagün', 'Kaygusuz', 'Kayrabay', 'Kayıt', 'Kaşif', 'Kelâmi',
                        'Kenter', 'Kerman', 'Kete', 'Kibar', 'Kiramettin', 'Kiyasi', 'Kocabaş',
                        'Koldan', 'Konguralp', 'Kopan', 'Koray', 'Korkmazalp', 'Korugan',
                        'Kotuz', 'Koçak', 'Koçkan', 'Koşukhan', 'Kuddusi', 'Kutay', 'Kâmil',
                        'Köker', 'Köktaş', 'Kösemen', 'Kürşad', 'Kılıçbay', 'Kınel', 'Kırat',
                        'Kırgız', 'Kıvılcım', 'Kızıl', 'Kızıltunç', 'Ledün', 'Lutfi', 'Lütfi',
                        'Mahir', 'Mahsun', 'Maksur', 'Mansurali', 'Masar', 'Mazlum', 'Mecit',
                        'Mefarettin', 'Mehmed', 'Mehmetzahir', 'Melihcan', 'Memili', 'Mengi',
                        'Mengüç', 'Merdi', 'Mertel', 'Merzuk', 'Mestur', 'Metinkaya', 'Mevlüt',
                        'Meşhur', 'Mihin', 'Milay', 'Mirbadin', 'Mishat', 'Monis', 'Mucahit',
                        'Muhammet', 'Muhip', 'Muhyettin', 'Muktedir', 'Muratcan', 'Musafet',
                        'Mutasım', 'Mutluhan', 'Muvaffak', 'Möhsim', 'Mücellib', 'Müfit',
                        'Mükramin', 'Mülâyim', 'Münif', 'Mürit', 'Müslum', 'Müzekker', 'Nabil',
                        'Nafii', 'Nakip', 'Nas', 'Nasuf', 'Nayil', 'Nazlim', 'Nebih', 'Necdat',
                        'Necmettin', 'Nehip', 'Nerim', 'Nesip', 'Nevsal', 'Nezihi', 'Nihai',
                        'Niyazi', 'Noman', 'Nural', 'Nurcan', 'Nuretdin', 'Nurkan', 'Nurullah',
                        'Nuyan', 'N˜zamett˜n', 'Odkanlı', 'Oganer', 'Okanay', 'Okbay',
                        'Okgüçlü', 'Okseven', 'Oktüremiş', 'Okyalaz', 'Olca', 'Oldağ', 'Oliver',
                        'Omaca', 'Onat', 'Ongay', 'Onuker', 'Onurcan', 'Onursu', 'Oranlı',
                        'Orgün', 'Ortak', 'Oruç', 'Otay', 'Oymak', 'Ozansü', 'Oğulbaş',
                        'Oğurata', 'Oğuzman', 'Paker', 'Pehlil', 'Pirahmet', 'Rabih', 'Rafih',
                        'Rahmet', 'Ramadan', 'Rasul', 'Razı', 'Recepali', 'Refik', 'Remazan',
                        'Resulcan', 'Rezzak', 'Risalet', 'Rohat', 'Ruhsat', 'Rüknettin',
                        'Rüşen', 'Saba', 'Sabih', 'Sadat', 'Sadittin', 'Safet', 'Sahir',
                        'Sakip', 'Salami', 'Salkın', 'Salurbay', 'Sami', 'Samurtay', 'Sancak',
                        'Sançar', 'Sargın', 'Sarpkın', 'Sarıcabay', 'Satrettin', 'Savak',
                        'Savni', 'Saydam', 'Sayin', 'Sayrak', 'Sayın', 'Sağcan', 'Sağıt',
                        'Sebattin', 'Seda', 'Seha', 'Selaheddin', 'Selatin', 'Seler', 'Selvi',
                        'Selâtin', 'Semender', 'Sencar', 'Seracettin', 'Serda', 'Serezli',
                        'Serhatmehmet', 'Serol', 'Server', 'Sevdi', 'Sevindik', 'Seydo',
                        'Seyfullah', 'Seyithan', 'Sezal', 'Sezginbaş', 'Seçme', 'Sidki',
                        'Siper', 'Sittik', 'Sonad', 'Songurkan', 'Soydaner', 'Soykut',
                        'Soyselçuk', 'Suat', 'Sudi', 'Sulhi', 'Sunel', 'Suphi', 'Sökmen',
                        'Sözer', 'Sücaettin', 'Süha', 'Sümeyye', 'Süvari', 'Sıla', 'Sıylıhan',
                        'Taciddin', 'Tahir', 'Talayer', 'Tali', 'Tamaydın', 'Tanak', 'Tanbay',
                        'Tandoğdu', 'Tanhan', 'Tanpınar', 'Tansev', 'Tansığ', 'Tanyolaç',
                        'Tanır', 'Tarancı', 'Tartış', 'Tatu', 'Tayaydın', 'Taygan', 'Taylak',
                        'Tayyip', 'Taşar', 'Taşkan', 'Teber', 'Tecimer', 'Tekbay', 'Tekecan',
                        'Tekiner', 'Teksoy', 'Telim', 'Temirhan', 'Temizkal', 'Temuçin',
                        'Tenvir', 'Terlan', 'Tevs', 'Tezcan', 'Tezol', 'Timurtaş', 'Tiğin',
                        'Toker', 'Toktuğ', 'Toköz', 'Tolonbay', 'Tonguç', 'Topuz', 'Torhan',
                        'Toy', 'Toğan', 'Tulun', 'Tunahan', 'Tunguç', 'Tunçboğa', 'Tunçkılıç',
                        'Turabi', 'Turgut', 'Tutkun', 'Tuyuğ', 'Tuğcan', 'Tuğrulhan', 'Tuğtaş',
                        'Törel', 'Tükelalp', 'Tümer', 'Tümkurt', 'Türabi', 'Türkalp', 'Türkmen',
                        'Tüzeer', 'Tınal', 'Ufukay', 'Ulakbey', 'Ulu', 'Uludağ', 'Uluman',
                        'Ulutay', 'Uluğbey', 'Umman', 'Umutcan', 'Uraltay', 'Urhan', 'Us',
                        'Ushan', 'Utkucan', 'Uygun', 'Uzbay', 'Uzsoy', 'Uçan', 'Uçbeyi', 'Uğan',
                        'Uğurkan', 'Uğurtan', 'Vafir', 'Vahittin', 'Vargın', 'Vaysal', 'Vedat',
                        'Veis', 'Velitdin', 'Verim', 'Vezat', 'Vâlâ', 'Yadigar', 'Yahşikan',
                        'Yalazabay', 'Yalgın', 'Yaltırak', 'Yalın', 'Yamin', 'Yankı', 'Yargı',
                        'Yasan', 'Yavuz', 'Yayak', 'Yazganalp', 'Yağın', 'Yağızkurt',
                        'Yaşattin', 'Yekda', 'Yelesen', 'Yeneral', 'Yertan', 'Yetişal', 'Yigit',
                        'Yilmaz', 'Yolal', 'Yoruç', 'Yunt', 'Yurdanur', 'Yurtgüven', 'Yurttaş',
                        'Yönetmen', 'Yücelen', 'Yümun', 'Yıldır', 'Yılma', 'Zahid', 'Zamir',
                        'Zekayi', 'Zennun', 'Zeynelabidin', 'Zihni', 'Ziyaettin', 'Zoral',
                        'Züfer', 'Zülgarni', 'Âdem', 'Çakar', 'Çakırca', 'Çaltı', 'Çamok',
                        'Çapkan', 'Çavuldur', 'Çağa', 'Çağdan', 'Çağlasın', 'Çağveren', 'Çelem',
                        'Çelikkan', 'Çelikyürek', 'Çerçi', 'Çetinsu', 'Çeviköz', 'Çinerk',
                        'Çokan', 'Çopur', 'Çoğay', 'Çıdal', 'Çıvgın', 'Öge', 'Ökkaş', 'Öktürk',
                        'Ömür', 'Öncel', 'Önel', 'Öngen', 'Önsal', 'Örik', 'Öryürek', 'Över',
                        'Özakan', 'Özalpsan', 'Özaslan', 'Özbay', 'Özbilek', 'Özdal', 'Özdil',
                        'Özdoğdu', 'Özel', 'Özerdinç', 'Özertem', 'Özger', 'Özgür', 'Özinal',
                        'Özkent', 'Özkutlu', 'Özlü', 'Özokçu', 'Özpınar', 'Özsözlü', 'Öztek',
                        'Öztürk', 'Özçam', 'Özüdoğru', 'Öğet', 'Übeydullah', 'Ülfet', 'Ülküdeş',
                        'Ümmet', 'Ünek', 'Ünlen', 'Ünsever', 'Ünübol', 'Ürfettin', 'Üsame',
                        'Üstün', 'Üzer', 'Ğanim', 'İbrahim', 'İdiris', 'İkiz', 'İlalmış',
                        'İlbek', 'İldem', 'İlgi', 'İlim', 'İlkim', 'İlmafer', 'İlsu', 'İlteriş',
                        'İmam', 'İmren', 'İnançlı', 'İntihap', 'İsak', 'İsmet', 'İvecen',
                        'İyiyürek', 'İzgü', 'İşcan', 'Şabettin', 'Şafii', 'Şahat', 'Şahinbey',
                        'Şahmettin', 'Şali', 'Şanlı', 'Şavki', 'Şefi', 'Şehamet', 'Şekim',
                        'Şemsettin', 'Şendoğan', 'Şenkal', 'Şerafeddin', 'Şevket', 'Şide',
                        'Şinasi', 'Şuayp', 'Şükri'

                        )

    first_names = first_names_male + first_names_female

    last_names = (
        'Yılmaz', 'Yıldırım', 'Türk', 'Yorulmaz', 'Erdoğan', 'Çorlu', 'Sakarya',
        'Demir', 'Yaman', 'Manço', 'Aksu', 'Akçay', 'Akar', 'Bilir', 'Bilgin',
        'Yüksel', 'Eraslan', 'Aslan', 'Arslan', 'Hançer', 'Hayrioğlu', 'Şama',
        'Ergül', 'Arsoy', 'Kısakürek', 'Gülen', 'Seven', 'Şafak', 'Dumanlı',
        'Ertaş', 'Güçlü', 'Soylu', 'Zorlu', 'Fırat', 'Duran', 'Durmuş', 'Durdu',
        'Zengin', 'Tevetoğlu', 'Mansız', 'Şener', 'Şensoy', 'Ülker', 'Tarhan',
        'Sezer', 'Demirel', 'Gül', 'Korutürk', 'İnönü', 'Öcalan', 'Çetin',
        'Sezgin', 'Alemdar', 'Karadeniz', 'Akdeniz', 'Bilge', 'Akgündüz',
        'Akçay', 'Çamurcuoğlu', 'İhsanoğlu', 'Akça'
    )

    prefixes_female = ('Bayan', 'Dr.')
    prefixes_male = ('Bay', 'Dr.')

    prefixes = prefixes_female + prefixes_male



# coding=utf-8
from __future__ import unicode_literals
from .. import Provider as PersonProvider


class Provider(PersonProvider):
    formats = (
        '{{first_name}} {{last_name}}',
        '{{first_name}} {{last_name}}',
        '{{first_name}} {{last_name}}',
        '{{first_name}} {{last_name}}',
        '{{first_name}} {{last_name}}',
        '{{prefix}} {{first_name}} {{last_name}}',
        '{{first_name}} {{last_name}}',
        '{{prefix}} {{first_name}} {{last_name}}'
    )

    first_names = (
        'Aaron', 'Akira', 'Alberto', 'Alessandro', 'Alighieri', 'Amedeo', 'Amos', 'Anselmo', 'Antonino', 'Arcibaldo',
        'Armando', 'Artes',
        'Audenico', 'Ausonio', 'Bacchisio', 'Battista', 'Bernardo', 'Boris', 'Caio', 'Carlo', 'Cecco', 'Cirino',
        'Cleros', 'Costantino',
        'Damiano', 'Danny', 'Davide', 'Demian', 'Dimitri', 'Domingo', 'Dylan', 'Edilio', 'Egidio', 'Elio', 'Emanuel',
        'Enrico', 'Ercole',
        'Ermes', 'Ethan', 'Eusebio', 'Evangelista', 'Fabiano', 'Ferdinando', 'Fiorentino', 'Flavio', 'Fulvio',
        'Gabriele', 'Gastone', 'Germano',
        'Giacinto', 'Gianantonio', 'Gianleonardo', 'Gianmarco', 'Gianriccardo', 'Gioacchino', 'Giordano', 'Giuliano',
        'Graziano', 'Guido', 'Harry',
        'Iacopo', 'Ilario', 'Ione', 'Italo', 'Jack', 'Jari', 'Joey', 'Joseph', 'Kai', 'Kociss', 'Laerte', 'Lauro',
        'Leonardo', 'Liborio', 'Lorenzo',
        'Ludovico', 'Maggiore', 'Manuele', 'Mariano', 'Marvin', 'Matteo', 'Mauro', 'Michael', 'Mirco', 'Modesto',
        'Muzio', 'Nabil', 'Nathan',
        'Nick', 'Noah', 'Odino', 'Olo', 'Oreste', 'Osea', 'Pablo', 'Patrizio', 'Piererminio', 'Pierfrancesco',
        'Piersilvio', 'Priamo', 'Quarto',
        'Quirino', 'Radames', 'Raniero', 'Renato', 'Rocco', 'Romeo', 'Rosalino', 'Rudy', 'Sabatino', 'Samuel', 'Santo',
        'Sebastian', 'Serse',
        'Silvano', 'Sirio', 'Tancredi', 'Terzo', 'Timoteo', 'Tolomeo', 'Trevis', 'Ubaldo', 'Ulrico', 'Valdo', 'Neri',
        'Vinicio', 'Walter', 'Xavier', 'Yago', 'Zaccaria', 'Abramo', 'Adriano', 'Alan', 'Albino', 'Alessio',
        'Alighiero',
        'Amerigo', 'Anastasio', 'Antimo', 'Antonio', 'Arduino', 'Aroldo', 'Arturo', 'Augusto', 'Avide', 'Baldassarre',
        'Bettino',
        'Bortolo', 'Caligola', 'Carmelo', 'Celeste', 'Ciro', 'Costanzo', 'Dante', 'Danthon', 'Davis', 'Demis', 'Dindo',
        'Domiziano', 'Edipo', 'Egisto', 'Eliziario', 'Emidio', 'Enzo', 'Eriberto', 'Erminio', 'Ettore', 'Eustachio',
        'Fabio', 'Fernando',
        'Fiorenzo', 'Folco', 'Furio', 'Gaetano', 'Gavino', 'Gerlando', 'Giacobbe', 'Giancarlo', 'Gianmaria', 'Giobbe',
        'Giorgio', 'Giulio',
        'Gregorio', 'Hector', 'Ian', 'Ippolito', 'Ivano', 'Jacopo', 'Jarno', 'Joannes', 'Joshua', 'Karim', 'Kris',
        'Lamberto',
        'Lazzaro', 'Leone', 'Lino', 'Loris', 'Luigi', 'Manfredi', 'Marco', 'Marino', 'Marzio', 'Mattia', 'Max',
        'Michele', 'Mirko', 'Moreno',
        'Nadir', 'Nazzareno', 'Nestore', 'Nico', 'Noel', 'Odone', 'Omar', 'Orfeo', 'Osvaldo', 'Pacifico', 'Pericle',
        'Pietro', 'Primo',
        'Quasimodo', 'Radio', 'Raoul', 'Renzo', 'Rodolfo', 'Romolo', 'Rosolino', 'Rufo', 'Sabino', 'Sandro', 'Sasha',
        'Secondo', 'Sesto',
        'Silverio', 'Siro', 'Tazio', 'Teseo', 'Timothy', 'Tommaso', 'Tristano', 'Umberto', 'Ariel', 'Artemide', 'Assia',
        'Azue', 'Benedetta',
        'Bibiana', 'Brigitta', 'Carmela', 'Cassiopea', 'Cesidia', 'Cira', 'Clea', 'Cleopatra', 'Clodovea', 'Concetta',
        'Cosetta', 'Cristyn',
        'Damiana', 'Danuta', 'Deborah', 'Demi', 'Diamante', 'Diana', 'Donatella', 'Doriana', 'Edvige', 'Elda', 'Elga',
        'Elsa', 'Emilia', 'Enrica',
        'Erminia', 'Eufemia', 'Evita', 'Fatima', 'Felicia', 'Filomena', 'Flaviana', 'Fortunata', 'Gelsomina',
        'Genziana', 'Giacinta', 'Gilda',
        'Giovanna', 'Giulietta', 'Grazia', 'Guendalina', 'Helga', 'Ileana', 'Ingrid', 'Irene', 'Isabel', 'Isira',
        'Ivonne', 'Jelena', 'Jole',
        'Claudia', 'Kayla', 'Kristel', 'Laura', 'Lucia', 'Lia', 'Lidia', 'Lisa', 'Loredana', 'Loretta', 'Luce',
        'Lucrezia', 'Luna', 'Maika',
        'Marcella', 'Maria', 'Mariagiulia', 'Marianita', 'Mariapia', 'Marieva', 'Marina', 'Maristella', 'Maruska',
        'Matilde', 'Mecren',
        'Mercedes', 'Mietta', 'Miriana', 'Miriam', 'Monia', 'Morgana', 'Naomi', 'Nayade', 'Nicoletta', 'Ninfa', 'Noemi',
        'Nunzia', 'Olimpia',
        'Oretta', 'Ortensia', 'Penelope', 'Piccarda', 'Prisca', 'Rebecca', 'Rita', 'Rosalba', 'Rosaria', 'Rosita',
        'Ruth', 'Samira',
        'Sarita', 'Selvaggia', 'Shaira', 'Sibilla', 'Soriana', 'Sue ellen', 'Thea', 'Tosca', 'Ursula', 'Vania', 'Vera',
        'Vienna', 'Violante', 'Vitalba', 'Zelida'
    )

    last_names = (
        'Rossi',
        'Russo',
        'Ferrari',
        'Esposito',
        'Bianchi',
        'Romano',
        'Colombo',
        'Ricci',
        'Marino',
        'Greco',
        'Bruno',
        'Gallo',
        'Conti',
        'De luca',
        'Mancini',
        'Costa',
        'Giordano',
        'Rizzo',
        'Lombardi',
        'Moretti',
        'Barbieri',
        'Fontana',
        'Santoro',
        'Mariani',
        'Rinaldi',
        'Caruso',
        'Ferrara',
        'Galli',
        'Martini',
        'Leone',
        'Longo',
        'Gentile',
        'Martinelli',
        'Vitale',
        'Lombardo',
        'Serra',
        'Coppola',
        'De Santis',
        'D\'angelo',
        'Marchetti',
        'Parisi',
        'Villa',
        'Conte',
        'Ferraro',
        'Ferri',
        'Fabbri',
        'Bianco',
        'Marini',
        'Grasso',
        'Valentini',
        'Messina',
        'Sala',
        'De Angelis',
        'Gatti',
        'Pellegrini',
        'Palumbo',
        'Sanna',
        'Farina',
        'Rizzi',
        'Monti',
        'Cattaneo',
        'Morelli',
        'Amato',
        'Silvestri',
        'Mazza',
        'Testa',
        'Grassi',
        'Pellegrino',
        'Carbone',
        'Giuliani',
        'Benedetti',
        'Barone',
        'Rossetti',
        'Caputo',
        'Montanari',
        'Guerra',
        'Palmieri',
        'Bernardi',
        'Martino',
        'Fiore',
        'De rosa',
        'Ferretti',
        'Bellini',
        'Basile',
        'Riva',
        'Donati',
        'Piras',
        'Vitali',
        'Battaglia',
        'Sartori',
        'Neri',
        'Costantini',
        'Milani',
        'Pagano',
        'Ruggiero',
        'Sorrentino',
        'D\'amico',
        'Orlando',
        'Damico',
        'Negri')

    prefixes_female = ('Dott.', 'Sig.ra')
    prefixes_male = ('Dott.', 'Sig.')

    prefixes = ('Dott.', 'Sig.', 'Sig.ra')
